@@ -19,6 +19,7 @@
 #' @param xname.formula Name of x in the equation
 #' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
+#' @param fontfamily Font family
 #' @details
 #' The Hill model is defined by:
 #' \deqn{y = \frac{a \times x^c}{b+x^c}}
@@ -51,10 +52,10 @@ hill=function(trat,
               round = NA,
               xname.formula="x",
               yname.formula="y",
-              comment=NA){
+              comment=NA,
+              fontfamily="sans"){
   requireNamespace("ggplot2")
   requireNamespace("drc")
-  requireNamespace("crayon")
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   ymean=tapply(resp,trat,mean)
   if(error=="SE"){ysd=tapply(resp,trat,sd)/sqrt(tapply(resp,trat,length))}
@@ -151,31 +152,44 @@ hill=function(trat,
   graph=graph+theme+
     geom_line(data=preditos,aes(x=x,y=y,color="black"))+
     scale_color_manual(name="",values=1,label=parse(text = equation))+
-    theme(axis.text = element_text(size=textsize,color="black"),
-          axis.title = element_text(size=textsize,color="black"),
+    theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
+          axis.title = element_text(size=textsize,color="black",family = fontfamily),
           legend.position = legend.position,
-          legend.text = element_text(size=textsize),
+          legend.text = element_text(size=textsize, family = fontfamily),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
-  temp1=seq(min(trat),max(trat),length.out=10000)
-  result=predict(mod,newdata = data.frame(trat=temp1),type="response")
-  aic=AIC(mod)
-  bic=BIC(mod)
-  print(coef)
   predesp=predict(mod)
   predobs=resp
   rmse=sqrt(mean((predesp-predobs)^2))
-  cat("\n===================================\n")
-  graphs=data.frame("Parameter"=c("AIC",
+  temp1=seq(min(trat),max(trat),length.out=10000)
+  result=predict(mod,newdata = data.frame(trat=temp1),
+                 type="response")
+  maximo=temp1[which.max(result)]
+  respmax=result[which.max(result)]
+  minimo=temp1[which.min(result)]
+  respmin=result[which.min(result)]
+  aic=AIC(mod)
+  bic=BIC(mod)
+  graphs=data.frame("Parameter"=c("X Maximum",
+                                  "Y Maximum",
+                                  "X Minimum",
+                                  "Y Minimum",
+                                  "AIC",
                                   "BIC",
                                   "r-squared",
                                   "RMSE"),
-                    "values"=c(aic,
+                    "values"=c(maximo,
+                               respmax,
+                               minimo,
+                               respmin,
+                               aic,
                                bic,
                                r2,
                                rmse))
-  graficos=list("teste"=graphs,graph)
+  graficos=list("Coefficients"=coef,
+                "values"=graphs,
+                graph)
   print(graficos)
 }
